@@ -79,14 +79,10 @@ public:
     void refreshViews();
 
     /**
-     * @param url The URL that we would like
-     * @return a QPair with first containing the index of the tab with the
-     * desired URL or -1 if not found. Second says true if URL is in primary
-     * view container, false otherwise. False means the URL is in the secondary
-     * view container, unless first == -1. In that case the value of second
-     * is meaningless.
+     * @return Whether any of the tab pages contains @p url in their primary
+     * or secondary view.
      */
-    QPair<int, bool> getIndexByUrl(const QUrl& url) const;
+    bool isUrlOpen(const QUrl& url) const;
 
 signals:
     /**
@@ -158,6 +154,16 @@ public slots:
      */
     void closeTab(const int index);
 
+    /**
+     * Activates the tab with the index \a index.
+     */
+    void activateTab(const int index);
+
+    /**
+     * Activates the last tab in the tab bar.
+     */
+    void activateLastTab();
+
     /**
      * Activates the next tab in the tab bar.
      * If the current active tab is the last tab, it activates the first tab.
@@ -221,6 +227,16 @@ private:
      */
     QString tabName(DolphinTabPage* tabPage) const;
 
+    /**
+     * @param url The URL that we would like
+     * @return a QPair with first containing the index of the tab with the
+     * desired URL or -1 if not found. Second says true if URL is in primary
+     * view container, false otherwise. False means the URL is in the secondary
+     * view container, unless first == -1. In that case the value of second
+     * is meaningless.
+     */
+    QPair<int, bool> indexByUrl(const QUrl& url) const;
+
 private:
     /** Caches the (negated) places panel visibility */
     bool m_placesSelectorVisible;
