@@ -21,14 +21,13 @@
 
 #include "dolphin_generalsettings.h"
 #include "dolphindebug.h"
+#include "dolphinmainwindowinterface.h"
 
 #include <KRun>
 #include <KWindowSystem>
 
 #include <QApplication>
 #include <QIcon>
-#include <QDBusInterface>
-#include <QDBusConnectionInterface>
 
 QList<QUrl> Dolphin::validateUris(const QStringList& uriList)
 {
@@ -72,44 +71,44 @@ void Dolphin::openNewWindow(const QList<QUrl> &urls, QWidget *window, const Open
 
 bool Dolphin::attachToExistingInstance(const QList<QUrl>& inputUrls, bool openFiles, bool splitView, const QString& preferredService)
 {
+    bool attached = false;
+
     // TODO: once Wayland clients can raise or activate themselves remove check from conditional
     if (KWindowSystem::isPlatformWayland() || inputUrls.isEmpty() || !GeneralSettings::openExternallyCalledFolderInNewTab()) {
         return false;
     }
 
-    QVector<QPair<QSharedPointer<QDBusInterface>, QStringList>> dolphinServices;
+    QVector<QPair<QSharedPointer<OrgKdeDolphinMainWindowInterface>, QStringList>> dolphinInterfaces;
     if (!preferredService.isEmpty()) {
-        QSharedPointer<QDBusInterface> preferred(
-            new QDBusInterface(preferredService,
-            QStringLiteral("/dolphin/Dolphin_1"),
-            QString()) // #414402: use empty interface name to prevent QtDBus from caching the interface.
-        );
-        if (preferred->isValid() && !preferred->lastError().isValid()) {
-            dolphinServices.append(qMakePair(preferred, QStringList()));
+        QSharedPointer<OrgKdeDolphinMainWindowInterface> preferredInterface(
+            new OrgKdeDolphinMainWindowInterface(preferredService,
+                QStringLiteral("/dolphin/Dolphin_1"),
+                QDBusConnection::sessionBus()));
+        if (preferredInterface->isValid() && !preferredInterface->lastError().isValid()) {
+            dolphinInterfaces.append(qMakePair(preferredInterface, QStringList()));
         }
     }
 
-    // find all dolphin instances
-    const QStringList services = QDBusConnection::sessionBus().interface()->registeredServiceNames().value();
+    // Look for dolphin instances among all available dbus services.
+    const QStringList dbusServices = QDBusConnection::sessionBus().interface()->registeredServiceNames().value();
     // Don't match the service without trailing "-" (unique instance)
     const QString pattern = QStringLiteral("org.kde.dolphin-");
     // Don't match the pid without leading "-"
     const QString myPid = QLatin1Char('-') + QString::number(QCoreApplication::applicationPid());
-    for (const QString& service : services) {
+    for (const QString& service : dbusServices) {
         if (service.startsWith(pattern) && !service.endsWith(myPid)) {
             // Check if instance can handle our URLs
-            QSharedPointer<QDBusInterface> instance(
-                new QDBusInterface(service,
-                QStringLiteral("/dolphin/Dolphin_1"),
-                QStringLiteral("org.kde.dolphin.MainWindow"))
-            );
-            if (instance->isValid() && !instance->lastError().isValid()) {
-                dolphinServices.append(qMakePair(instance, QStringList()));
+            QSharedPointer<OrgKdeDolphinMainWindowInterface> interface(
+                        new OrgKdeDolphinMainWindowInterface(service,
+                            QStringLiteral("/dolphin/Dolphin_1"),
+                            QDBusConnection::sessionBus()));
+            if (interface->isValid() && !interface->lastError().isValid()) {
+                dolphinInterfaces.append(qMakePair(interface, QStringList()));
             }
         }
     }
 
-    if (dolphinServices.isEmpty()) {
+    if (dolphinInterfaces.isEmpty()) {
         return false;
     }
 
@@ -119,10 +118,11 @@ bool Dolphin::attachToExistingInstance(const QList<QUrl>& inputUrls, bool openFi
     const auto urls = QUrl::toStringList(inputUrls);
     for (const QString& url : urls) {
         bool urlFound = false;
-        for (auto& service: dolphinServices) {
-            QDBusReply<bool> isUrlOpen = service.first->call(QStringLiteral("isUrlOpen"), url);
-            if (isUrlOpen.isValid() && isUrlOpen.value()) {
-                service.second.append(url);
+        for (auto& interface: dolphinInterfaces) {
+            auto isUrlOpenReply = interface.first->isUrlOpen(url);
+            isUrlOpenReply.waitForFinished();
+            if (!isUrlOpenReply.isError() && isUrlOpenReply.value()) {
+                interface.second.append(url);
                 urlFound = true;
                 break;
             }
@@ -131,13 +131,17 @@ bool Dolphin::attachToExistingInstance(const QList<QUrl>& inputUrls, bool openFi
             newUrls.append(url);
         }
     }
-    dolphinServices.front().second << newUrls;
+    dolphinInterfaces.front().second << newUrls;
 
-    for (const auto& service: dolphinServices) {
-        if (!service.second.isEmpty()) {
-            service.first->call(openFiles ? QStringLiteral("openFiles") : QStringLiteral("openDirectories"), service.second, splitView);
-            service.first->call(QStringLiteral("activateWindow"));
+    for (const auto& interface: dolphinInterfaces) {
+        if (!interface.second.isEmpty()) {
+            auto reply = openFiles ? interface.first->openFiles(interface.second, splitView) : interface.first->openDirectories(interface.second, splitView);
+            reply.waitForFinished();
+            if (!reply.isError()) {
+                interface.first->activateWindow();
+                attached = true;
+            }
         }
     }
-    return true;
+    return attached;
 }
