@@ -19,28 +19,53 @@
 
 #include "dolphinquery.h"
 
+#include <QRegularExpression>
+
 #include <config-baloo.h>
 #ifdef HAVE_BALOO
 #include <Baloo/Query>
 #endif
 
 namespace {
-    /** Checks if a given term in the Baloo::Query::searchString() is a special search term.
-     * This is a copy of `DolphinFacetsWidget::isRatingTerm()` method.
+    /** Checks if a given term in the Baloo::Query::searchString() is a special search term
+     * @return: the specific search token of the term, or an empty QString() if none is found
      */
-    bool isSearchTerm(const QString& term)
+    QString searchTermToken(const QString& term)
     {
         static const QLatin1String searchTokens[] {
+            QLatin1String("filename:"),
             QLatin1String("modified>="),
-            QLatin1String("rating>=")
+            QLatin1String("rating>="),
+            QLatin1String("tag:"), QLatin1String("tag=")
         };
 
         for (const auto &searchToken : searchTokens) {
             if (term.startsWith(searchToken)) {
-                return true;
+                return searchToken;
             }
         }
-        return false;
+        return QString();
+    }
+
+    QString stripQuotes(const QString& text)
+    {
+        if (text.length() >= 2 && text.at(0) == QLatin1Char('"')
+                               && text.back() == QLatin1Char('"')) {
+            return text.mid(1, text.size() - 2);
+        }
+        return text;
+    }
+
+    QStringList splitOutsideQuotes(const QString& text)
+    {
+        const QRegularExpression subTermsRegExp("(\\S*?\"[^\"]*?\"|(?<=\\s|^)\\S+(?=\\s|$))");
+        auto subTermsMatchIterator = subTermsRegExp.globalMatch(text);
+
+        QStringList textParts;
+        while (subTermsMatchIterator.hasNext()) {
+            textParts << subTermsMatchIterator.next().captured(0);
+        }
+        return textParts;
     }
 }
 
@@ -58,29 +83,35 @@ DolphinQuery DolphinQuery::fromBalooSearchUrl(const QUrl& searchUrl)
     model.m_fileType = types.isEmpty() ? QString() : types.first();
 
     QStringList textParts;
+    QString fileName;
 
-    const QStringList subTerms = query.searchString().split(' ', QString::SkipEmptyParts);
+    const QStringList subTerms = splitOutsideQuotes(query.searchString());
     foreach (const QString& subTerm, subTerms) {
-        QString value;
-        if (subTerm.startsWith(QLatin1String("filename:"))) {
-            value = subTerm.mid(9);
-        } else if (isSearchTerm(subTerm)) {
-            model.m_searchTerms << subTerm;
+        const QString token = searchTermToken(subTerm);
+        const QString value = stripQuotes(subTerm.mid(token.length()));
+
+        if (token == QLatin1String("filename:")) {
+            if (!value.isEmpty()) {
+                fileName = value;
+                model.m_hasFileName = true;
+            }
+            continue;
+        } else if (!token.isEmpty()) {
+            model.m_searchTerms << token + value;
             continue;
         } else if (subTerm == QLatin1String("AND") && subTerm != subTerms.at(0) && subTerm != subTerms.back()) {
             continue;
-        } else {
-            value = subTerm;
-        }
-
-        if (!value.isEmpty() && value.at(0) == QLatin1Char('"')) {
-            value = value.mid(1);
-        }
-        if (!value.isEmpty() && value.back() == QLatin1Char('"')) {
-            value = value.mid(0, value.size() - 1);
-        }
-        if (!value.isEmpty()) {
+        } else if (!value.isEmpty()) {
             textParts << value;
+            model.m_hasContentSearch = true;
+        }
+    }
+
+    if (model.m_hasFileName) {
+        if (model.m_hasContentSearch) {
+            textParts << QStringLiteral("filename:\"%1\"").arg(fileName);
+        } else {
+            textParts << fileName;
         }
     }
 
@@ -114,3 +145,13 @@ QString DolphinQuery::includeFolder() const
 {
     return m_includeFolder;
 }
+
+bool DolphinQuery::hasContentSearch() const
+{
+    return m_hasContentSearch;
+}
+
+bool DolphinQuery::hasFileName() const
+{
+    return m_hasFileName;
+}
