@@ -374,6 +374,12 @@ public slots:
      */
     void pasteIntoFolder();
 
+    /**
+     * Creates duplicates of selected items, appending "copy"
+     * to the end.
+     */
+    void duplicateSelectedItems();
+
     /**
      * Handles a drop of @p dropEvent onto widget @p dropWidget and destination @p destUrl
      */
