@@ -33,6 +33,7 @@
 
 class KFileItemList;
 class KFileItemModel;
+class KItemRangeList;
 class QAction;
 class QTimer;
 class UpdateItemStatesThread;
@@ -97,6 +98,12 @@ private slots:
      */
     void silentDirectoryVerification();
 
+    /**
+     * Invokes delayedDirectoryVerification() only if the itemsChanged() signal has not
+     * been triggered by the VCS plugin itself.
+     */
+    void slotItemsChanged(const KItemRangeList& itemRanges, const QSet<QByteArray>& roles);
+
     void verifyDirectory();
 
     /**
@@ -107,6 +114,7 @@ private slots:
 
 private:
     typedef QPair<KFileItem, KVersionControlPlugin::ItemVersion> ItemState;
+    typedef QPair<KVersionControlPlugin*, QString> VCSPlugin;
 
     void updateItemStates();
 
@@ -150,7 +158,7 @@ private:
 
     bool m_pluginsInitialized;
     KVersionControlPlugin* m_plugin;
-    QList<KVersionControlPlugin*> m_plugins;
+    QList<VCSPlugin> m_plugins;
     UpdateItemStatesThread* m_updateItemStatesThread;
 
     friend class UpdateItemStatesThread;
